# filter out some devel() and pkgconfig() provides
# which are already provided by openssl-devel
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}devel\\(lib(ssl|crypto)
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}pkgconfig\\(lib(ssl|crypto)

# same for requires to not require openssl-devel
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(lib(ssl|crypto)
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}pkgconfig\\(lib(ssl|crypto)

%define crypto_major 37
%define crypto_libname %mklibname crypto %{crypto_major}

%define ssl_major 38
%define ssl_libname %mklibname ssl %{ssl_major}

%define tls_major 10
%define tls_libname %mklibname tls %{tls_major}

%define develname %mklibname -d libressl

# Builds in mock in CentOS 7
#  dev package conflicts with openssl-dev - intentional
#  A system should not have both dev packages installed together
# man3 pages in own sub-package
#  dev package usually only installed by build system. Keeping
#  man pages separate avoids possible name conflict with man
#  pages from other dev packages, man pages not needed in build
#  system
# openssl binary renamed to libressl
#  allows parallel install with vendor openssl without weird
#  paths or confusion. Man page also renamed.
# RPM spec file only tested in CentOS 7 x86_64

%define ssldir %{_sysconfdir}/pki/tls

Summary: OpenBSD fork of the OpenSSL Cryptography Suite
Name: libressl
Version: 2.3.2
Release: %mkrel 1
Group: System/Libraries
License: BSD-like
URL: http://www.libressl.org/
Source0: http://ftp.openbsd.org/pub/OpenBSD/LibreSSL/libressl-%{version}.tar.gz
Source1: libressl-awel-additions.cnf
Patch80: libressl-2.3.1-disable_ssl2_handshake.diff
Patch90: libressl-2.3.1-cnf-name.diff
Patch91: libressl-2.3.1-man1-libressl.diff
Patch92: libressl-2.3.1-man3-libressl.diff
BuildRequires: libtool autoconf automake

%description
LibreSSL is a fork of OpenSSL 1.0.1g developed by the OpenBSD project.
Our goal is to modernize the codebase, improve security, and apply best
practice development processes from OpenBSD.

%package common
Summary: Common files for LibreSSL
Group: System/Libraries
Requires: rootcerts

%description common
This package provides common files for LibreSSL.

%package -n %{crypto_libname}
Summary: Shared Crypto library for LibreSSL
Group: System/Libraries
Requires: %{name}-common = %{version}-%{release}

%description -n %{crypto_libname}
This package provides the shared crypto library for LibreSSL.

LibreSSL is API compatible with OpenSSL 1.0.1, but does not yet include all
new APIs from OpenSSL 1.0.2 and later. LibreSSL also includes APIs not yet
present in OpenSSL. The current common API subset is OpenSSL 1.0.1.

LibreSSL it is not ABI compatible with any release of OpenSSL, or necessarily
earlier releases of LibreSSL. You will need to relink your programs to
LibreSSL in order to use it, just as in moving between major versions of
OpenSSL.

LibreSSL's installed library version numbers are incremented to account for
ABI and API changes.

%package -n %{ssl_libname}
Summary: Shared SSL library for LibreSSL
Group: System/Libraries
Requires: %{name}-common = %{version}-%{release}

%description -n %{ssl_libname}
This package provides the shared ssl library for LibreSSL.

LibreSSL is API compatible with OpenSSL 1.0.1, but does not yet include all
new APIs from OpenSSL 1.0.2 and later. LibreSSL also includes APIs not yet
present in OpenSSL. The current common API subset is OpenSSL 1.0.1.

LibreSSL it is not ABI compatible with any release of OpenSSL, or necessarily
earlier releases of LibreSSL. You will need to relink your programs to
LibreSSL in order to use it, just as in moving between major versions of
OpenSSL.

LibreSSL's installed library version numbers are incremented to account for
ABI and API changes.

%package -n %{tls_libname}
Summary: Shared TLS library for LibreSSL
Group: System/Libraries
Requires: %{name}-common = %{version}-%{release}

%description -n %{tls_libname}
This package provides the shared tls library for LibreSSL.

LibreSSL is API compatible with OpenSSL 1.0.1, but does not yet include all
new APIs from OpenSSL 1.0.2 and later. LibreSSL also includes APIs not yet
present in OpenSSL. The current common API subset is OpenSSL 1.0.1.

LibreSSL it is not ABI compatible with any release of OpenSSL, or necessarily
earlier releases of LibreSSL. You will need to relink your programs to
LibreSSL in order to use it, just as in moving between major versions of
OpenSSL.

LibreSSL's installed library version numbers are incremented to account for
ABI and API changes.

%package -n %{develname}
Summary: Developer files for LibreSSL
Group: Development/C
Conflicts: openssl-devel
Provides: %{name}-devel = %{version}-%{release}
Requires: %{crypto_libname} = %{version}-%{release}
Requires: %{ssl_libname} = %{version}-%{release}
Requires: %{tls_libname} = %{version}-%{release}

%description -n	%{develname}
This package provides the development header files for LibreSSL.

%prep

%setup -q
%patch80 -p1
%patch90 -p1
%patch91 -p1
%patch92 -p1

cd apps/openssl
mv openssl.1 libressl.1
cd ../..

%build
autoreconf -vfi

%configure2_5x \
  --with-openssldir=%{ssldir}

# fails biotest \
#  --enable-extratests

##%% from RHEL/CentOS OpenSSL spec file ##%%
# Add -Wa,--noexecstack here so that libcrypto's assembler modules will be
# marked as not requiring an executable stack.
# Also add -DPURIFY to make using valgrind with openssl easier as we do not
# want to depend on the uninitialized memory as a source of entropy anyway.
RPM_OPT_FLAGS="%{optflags} -Wa,--noexecstack -DPURIFY"

%make

%check
make check

%install
%makeinstall_std

install -d %{buildroot}%{ssldir}/csr
install -d %{buildroot}%{ssldir}/cert_bundle

#rename openssl binary
mv %{buildroot}%{_bindir}/openssl %{buildroot}%{_bindir}/libressl

#customize conf
cat %{SOURCE1} >> %{buildroot}%{_sysconfdir}/pki/tls/libressl.cnf

#fix permissions
chmod 755 %{buildroot}%{_libdir}/lib*.0.0

#DH parameter generation cronjobs
mkdir -p %{buildroot}%{_sysconfdir}/cron.daily
mkdir -p %{buildroot}%{_sysconfdir}/cron.weekly
cat <<EOF > %{buildroot}%{_sysconfdir}/cron.daily/generate_dh_params.sh
#!/bin/bash
TMPFILE="\`%{_bindir}/mktemp -p /tmp dhparams.XXXXXXXXXX\`"

trap "rm -f \${TMPFILE}" EXIT TERM

%{_bindir}/nice -n19 %{_bindir}/libressl dhparam -out \${TMPFILE} 1024 > /dev/null 2>&1
if [ \$? -eq 0 ]; then
  cat \${TMPFILE} > %{_sysconfdir}/pki/tls/dh1024.pem
fi
%{_bindir}/nice -n19 %{_bindir}/libressl dhparam -out \${TMPFILE} 2048 > /dev/null 2>&1
if [ \$? -eq 0 ]; then
  cat \${TMPFILE} > %{_sysconfdir}/pki/tls/dh2048.pem
fi
EOF
cat <<EOF > %{buildroot}%{_sysconfdir}/cron.weekly/generate_dh_params.sh
#!/bin/bash
TMPFILE="\`%{_bindir}/mktemp -p /tmp dhparams.XXXXXXXXXX\`"

trap "rm -f \${TMPFILE}" EXIT TERM

%{_bindir}/nice -n19 %{_bindir}/libressl dhparam -out \${TMPFILE} 3072 > /dev/null 2>&1
if [ \$? -eq 0 ]; then
  cat \${TMPFILE} > %{_sysconfdir}/pki/tls/dh3072.pem
fi
%{_bindir}/nice -n19 %{_bindir}/libressl dhparam -out \${TMPFILE} 4096 > /dev/null 2>&1
if [ \$? -eq 0 ]; then
  cat \${TMPFILE} > %{_sysconfdir}/pki/tls/dh4096.pem
fi
EOF
touch %{buildroot}%{_sysconfdir}/pki/tls/dh1024.pem
touch %{buildroot}%{_sysconfdir}/pki/tls/dh2048.pem
touch %{buildroot}%{_sysconfdir}/pki/tls/dh3072.pem
touch %{buildroot}%{_sysconfdir}/pki/tls/dh4096.pem

# cleanup
rm -f %{buildroot}%{ssldir}/cert.pem
rm -f %{buildroot}%{_libdir}/*.*a

# have to rename this one for now, otherwise there will be quite stressful times...
mv %{buildroot}%{_libdir}/pkgconfig/openssl.pc %{buildroot}%{_libdir}/pkgconfig/libressl.pc

%files
%attr(0755,root,root) %{_sysconfdir}/cron.daily/generate_dh_params.sh
%attr(0755,root,root) %{_sysconfdir}/cron.weekly/generate_dh_params.sh
%{_bindir}/libressl
%{_mandir}/man1/libressl.*

%files common
%doc COPYING
%dir %{ssldir}/certs
%dir %{ssldir}/csr
%dir %{ssldir}/cert_bundle
%attr(0644,root,root) %config(noreplace) %{ssldir}/libressl.cnf
%attr(0644,root,root) %config(noreplace) %{ssldir}/x509v3.cnf
%attr(0644,root,root) %ghost %{ssldir}/dh1024.pem
%attr(0644,root,root) %ghost %{ssldir}/dh2048.pem
%attr(0644,root,root) %ghost %{ssldir}/dh3072.pem
%attr(0644,root,root) %ghost %{ssldir}/dh4096.pem

%files -n %{crypto_libname}
%{_libdir}/*.so.%{crypto_major}*

%files -n %{ssl_libname}
%{_libdir}/*.so.%{ssl_major}*

%files -n %{tls_libname}
%{_libdir}/*.so.%{tls_major}*

%files -n %{develname}
%doc ChangeLog
%{_includedir}/tls.h
%{_includedir}/openssl/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*



%changelog
* Thu Feb 04 2016 oden <oden> 2.3.2-1.mga6
+ Revision: 935632
- 2.3.2

* Sat Jan 02 2016 wally <wally> 2.3.1-4.mga6
+ Revision: 918428
- filter out also requires to not require openssl-devel

* Sat Jan 02 2016 wally <wally> 2.3.1-3.mga6
+ Revision: 918418
- fix provides excludes

* Sat Jan 02 2016 wally <wally> 2.3.1-2.mga6
+ Revision: 918409
- filter out devel() and pkgconfig() provides which are already provided by openssl-devel

* Tue Nov 24 2015 oden <oden> 2.3.1-1.mga6
+ Revision: 905744
- imported package libressl

